@@ -1,5 +1,5 @@
 /*
-  Copyright 1997-2023 Sam Lantinga
+  Copyright 1997-2025 Sam Lantinga
   Copyright 2022 Collabora Ltd.
 
   This software is provided 'as-is', without any express or implied
@@ -237,6 +237,7 @@ static const Format formats[] =
         IMG_isJPG,
         IMG_LoadJPG_RW,
     },
+#if 0 /* Different versions of JXL yield different output images */
     {
         "JXL",
         "sample.jxl",
@@ -254,6 +255,7 @@ static const Format formats[] =
         IMG_isJXL,
         IMG_LoadJXL_RW,
     },
+#endif
 #if 0
     {
         "LBM",
@@ -303,7 +305,11 @@ static const Format formats[] =
 #else
         SDL_FALSE,
 #endif
-        SDL_IMAGE_SAVE_PNG,
+#ifdef SDL_IMAGE_SAVE_PNG
+        SDL_IMAGE_SAVE_PNG ? SDL_TRUE : SDL_FALSE,
+#else
+        SDL_FALSE,
+#endif
         IMG_isPNG,
         IMG_LoadPNG_RW,
     },
@@ -1027,7 +1033,7 @@ main(int argc, char *argv[])
             }
             else if (SDL_strcasecmp(argv[i], "--execKey") == 0) {
                 if (argv[i + 1]) {
-                    SDL_sscanf(argv[i + 1], "%"SDL_PRIu64, &userExecKey);
+                    SDL_sscanf(argv[i + 1], "%" SDL_PRIu64, &userExecKey);
                     consumed = 2;
                 }
             }
